% FontExample1.m
% This example shows the Matlab font problem when exporting vector graphics
% using 'print' function with '-printer' driver
%
% Author: Juan M. Guerrero
% Institution: Universidad de Oviedo (Spain)
% Date: 04/21/2017


% 1 - Create a 18x10 cm figure to illustrate the example
close all % Optional, in case you want to get rid of all previous figures
fig = figure;
fig.Units = 'centimeters';
width = 18; % cm
height = 10; % cm
fig.Position = [fig.Position(1) fig.Position(2) width height]; % 10x10 cm
ax=axes; % Create an axis for the font example


% 2- Write some text and labels with different fonts(beware: select fonts installed
% in your system)
ax.FontName = 'Elephant'; 
text(.1,.9,'This font is Comic Sans MS','fontname','Comic Sans MS','fontsize',12);
text(.1,.75,'This font is Vladimir Script','fontname','Vladimir Script','fontsize',12);
text(.1,.6,'And this is Lucida Fax Italic','fontname','Lucida Fax','fontangle','italic','fontsize',12);
text(.4,.05,'For your eyes-only (Colonna MT)','fontname','Colonna MT','fontsize',20,'rotation',45);
xl = xlabel('Nice x-label in Calibri','fontname','Calibri','fontsize',12);
yl = ylabel('y-label is Jokerman font','fontname','Jokerman','fontsize',12);

% 3- Obtain the eps file using print
file_name = 'Example1';
set(fig,'paperpositionmode','auto','units','centimeters','paperunits','centimeters','papersize',[width height]);
print(fig,'-depsc','-painters','-r600','-loose',strcat('.\',file_name));   % eps 

%4- Obtain the pdf file using epstopdf (included for instance in MikTex)
system(sprintf('epstopdf --gsopt="-sFONTPATH=C:/Windows/Fonts  -dSubsetFonts=true  -dEmbedAllFonts=true -dPDFSETTINGS=/prepress" "%s.eps"',strcat('.\',file_name))); 
 
%5- Open the pdf with the viewer of your choice (Sumatra in this case). Or remove this and open it manually
system(sprintf('"C:/Program Files/SumatraPDF/SumatraPDF.exe" -reuse-instance %s',strcat('.\',file_name,'.pdf &')));