% FontExample3.m
% This example shows how to correct the Matlab font problem when exporting vector graphics
% using 'print' function with '-printer' driver. Includes label position
% correction.
%
%
% Author: Juan M. Guerrero
% Institution: Universidad de Oviedo (Spain)
% Date: 04/21/2017


% 1 - Create a 18x10 cm figure to illustrate the example
close all % Optional, in case you want to get rid of all previous figures
fig = figure;
fig.Units = 'centimeters';
width = 18; % cm
height = 10; % cm
fig.Position = [fig.Position(1) fig.Position(2) width height]; % 10x10 cm
ax=axes; % Create an axis for the font example


% 2- Write some text and labels with different fonts(beware: select fonts installed
% in your system)
ax.FontName = 'Elephant'; 
text(.1,.9,'This font is Comic Sans MS','fontname','Comic Sans MS','fontsize',12);
text(.1,.75,'This font is Vladimir Script','fontname','Vladimir Script','fontsize',12);
text(.1,.6,'And this is Lucida Fax Italic','fontname','Lucida Fax','fontangle','italic','fontsize',12);
text(.4,.05,'For your eyes-only (Colonna MT)','fontname','Colonna MT','fontsize',20,'rotation',45);
xl = xlabel('Nice x-label in Calibri','fontname','Calibri','fontsize',12);
yl = ylabel('y-label is Jokerman font','fontname','Jokerman','fontsize',12);

% 3- Calculate the original label position
xl.Units = 'pixels';
xl.Margin = 1;
xl_hpos = xl.Extent(1)+1;
yl.Units = 'pixels';
yl.Margin = 1;
yl_vpos = yl.Extent(2)+1;

% 4- Preprocess. Remap the fonts to the Matlab subset
% Find font objects
font1 = findall(gcf,'fontname','Elephant');
font2 = findall(gcf,'fontname','Comic Sans MS');
font3 = findall(gcf,'fontname','Vladimir Script');
font4 = findall(gcf,'fontname','Lucida Fax','fontangle','italic');
font5 = findall(gcf,'fontname','Colonna MT');
font6 = findall(gcf,'fontname','Calibri');
font7 = findall(gcf,'fontname','Jokerman');

% Replace fonts
% Important Note: axes font must be remapped BEFORE the xlabel and ylabel
% remap (1, before 6 and 7 in this example)
set(font1,'fontname','Helvetica'); % Remap to Helvetica
set(font2,'fontname','Helvetica','fontweight','bold'); % Remap to Helvetica-Bold
set(font3,'fontname','Helvetica','fontangle','italic'); %  Remap to Helvetica-Oblique
set(font4,'fontname','Helvetica','fontangle','italic','fontweight','bold'); %  Remap to Helvetica-BoldOblique
set(font5,'fontname','Courier'); %  Remap to Courier
set(font6,'fontname','Courier','fontweight','bold'); %  Remap to Courier-Bold
set(font7,'fontname','Courier','fontangle','italic'); %  Remap to Courier-Oblique

% Restore label left positions
xl.HorizontalAlignment = 'left';
xl.Position= [xl_hpos xl.Position(2) xl.Position(3)]; 

yl.HorizontalAlignment = 'left';
yl.Position= [yl.Position(1) yl_vpos yl.Position(3)]; 

ax.XTick=[0:.2:1]; % to force a particular tick labeling

% 5- Obtain the eps file using print
file_name = 'Example3';
set(fig,'paperpositionmode','auto','units','centimeters','paperunits','centimeters','papersize',[width height]);
print(fig,'-depsc','-painters','-r600','-loose',strcat('.\',file_name));   % eps 


% 6- Postprocess (recover the fonts in figure)
set(font1,'fontname','Elephant','fontangle','normal','fontweight','light');
set(font2,'fontname','Comic Sans MS','fontangle','normal','fontweight','light');
set(font3,'fontname','Vladimir Script','fontangle','normal','fontweight','light');
set(font4,'fontname','Lucida Fax','fontangle','italic','fontweight','light');
set(font5,'fontname','Colonna MT','fontangle','normal','fontweight','light');
set(font6,'fontname','Calibri','fontangle','normal','fontweight','light');
set(font7,'fontname','Jokerman','fontangle','normal','fontweight','light');


% 7- Obtain the pdf file using epstopdf (included for instance in MikTex)
system(sprintf('epstopdf --gsopt="-sFONTMAP=""K:/Documentos archivados/M Files/Megaplot/FontExample2.gs""  -sFONTPATH=C:/Windows/Fonts  -dSubsetFonts=true  -dEmbedAllFonts=true -dPDFSETTINGS=/prepress" "%s.eps"',strcat('.\',file_name)));


% 8- Open the pdf with the viewer of your choice (Sumatra in this case). Or remove this and open it manually
system(sprintf('"C:/Program Files/SumatraPDF/SumatraPDF.exe" -reuse-instance %s',strcat('.\',file_name,'.pdf &')));