% FontExample5.m
% This example shows how to modify the LaTeX interpreter fonts in pdf
% production
%
% Author: Juan M. Guerrero
% Institution: Universidad de Oviedo (Spain)
% Date: 04/21/2017


% 1 - Create a 18x10 cm figure to illustrate the example
close all % Optional, in case you want to get rid of all previous figures
fig = figure;
fig.Units = 'centimeters';
width = 18; % cm
height = 10; % cm
fig.Position = [fig.Position(1) fig.Position(2) width height]; % 10x10 cm
ax=axes; % Create an axis for the font example


% 2- Write some text and labels with different fonts(beware: select fonts installed
% in your system)
ax.FontName = 'Times New Roman'; 
text(.05,1,'\textnormal{This is textnormal} (mwa\_cmr10)','interpreter','latex','fontsize',12);
text(.05,.9,'\textrm{This is textrm (mwa\_cmr10)}','interpreter','latex','fontsize',12);
text(.05,.8,'\textit{This is textit (mwa\_cmti10)}','interpreter','latex','fontsize',12);
text(.05,.7,'\textbf{This is textbf (mwa\_cmbx10)}','interpreter','latex','fontsize',12);
text(.05,.6,'\texttt{This is textt (mwa\_cmtt10)}','interpreter','latex','fontsize',12);
text(.05,.5,'\textsl{This is textsl (mwa\_cmsl10)}','interpreter','latex','fontsize',12);

text(.6,1,'$\mathnormal{This~is~mathnormal (mwa\_cmmi10)}$','interpreter','latex','fontsize',12);
text(.65,.9,'$\mathrm{This~is~mathrm (mwa\_cmr10)}$','interpreter','latex','fontsize',12);
text(.65,.8,'$\mathit{This~is~mathit (mwa\_cmti10)}$','interpreter','latex','fontsize',12);
text(.65,.7,'$\mathbf{This~is~mathbf (mwa\_cmbx10)}$','interpreter','latex','fontsize',12);
text(.65,.6,'$\mathtt{This~is~mathtt (mwa\_cmtt10)}$','interpreter','latex','fontsize',12);
text(.65,.5,'$\mathcal{This~is~mathcal (mwa\_cmsy10)}$','interpreter','latex','fontsize',12);
text(.65,.4,'Above: mathcal (mwa\_cmsy10)','interpreter','latex','fontsize',12);

text(.05,.2,'This mixes text and math: $ G(s)  =\frac{s^2 + 2 s +2}{s^3 + 2s +1}$ \bf and text again','interpreter','latex','fontsize',12);

xl = xlabel('Nice x-label in Latex $\lambda = \frac{\infty}{0}$','interpreter','latex','fontsize',12);
yl = ylabel('y-label $\mathbf{A} \frac{\mathbf{\alpha}}{\sum \gamma}$','interpreter','latex','fontsize',12);


% 4- Preprocess. Remap the fonts to the Matlab subset
% Find font objects
font1 = findall(gcf,'fontname','Times New Roman');

% Replace fonts
set(font1,'fontname','Times-Roman'); % Remap to Times-Roman

% 5- Obtain the eps file using print
file_name = 'Example5';
set(fig,'paperpositionmode','auto','units','centimeters','paperunits','centimeters','papersize',[width height]);
print(fig,'-depsc','-painters','-r600','-loose',strcat('.\',file_name));   % eps 

% 6- Postprocess (recover the fonts in figure)
set(font1,'fontname','Times New Roman','fontangle','normal','fontweight','light');

% 7- Search and replace latex fonts for Matlab fonts
fid = fopen(strcat('.\',file_name,'.eps'));
ff = char(fread(fid))';  % A large string with the file contents
fclose(fid);
% 
index = min(strfind(ff,'/mwa_cmr10')); % Serach for the font you want to replace
ff  = strcat(ff(1:index+9),strrep(ff(index+10:end),'/mwa_cmr10','/Helvetica')); % Substitute for one of the Matlab fonts    

% % open the file up and overwrite it
fid = fopen(strcat('.\',file_name,'.eps'),'w');
fprintf(fid,'%s',ff);
fclose(fid);

% 7- Obtain the pdf file using epstopdf (included for instance in MikTex)
system(sprintf('epstopdf --gsopt="-sFONTMAP=""K:/Documentos archivados/M Files/Megaplot/FontExample5.gs""  -sFONTPATH=C:/Windows/Fonts  -dSubsetFonts=true  -dEmbedAllFonts=true -dPDFSETTINGS=/prepress" "%s.eps"',strcat('.\',file_name))); 

% 8- Open the pdf with the viewer of your choice (Sumatra in this case). Or remove this and open it manually
system(sprintf('"C:/Program Files/SumatraPDF/SumatraPDF.exe" -reuse-instance %s',strcat('.\',file_name,'.pdf &')));