% FontExample6.m
% This example shows how to combine the LaTeX and default interpreter
%
% Author: Juan M. Guerrero
% Institution: Universidad de Oviedo (Spain)
% Date: 04/21/2017

% 1 - Create a 18x10 cm figure to illustrate the example
close all % Optional, in case you want to get rid of all previous figures
fig = figure;
fig.Units = 'centimeters';
width = 18; % cm
height = 10; % cm
fig.Position = [fig.Position(1) fig.Position(2) width height]; % 10x10 cm
ax=axes; % Create an axis for the font example


% 2- Write some text and labels with different fonts(beware: select only
% fonts installed in your system

% A mixed latex and other fonts x-label
% Create the label in LaTex to get the position
xl=xlabel('{Time (s)} $\lambda_r = \frac{di}{dt}$ and so on','Interpreter','latex','fontsize',12,'margin',1,'Units','pixels');
% Create the text replacements
t1= text(0,0,'Time (s) ','fontsize',12,'fontname','Harrington','Units','pixels');
t1.VerticalAlignment = xl. VerticalAlignment;
t1.Position = [xl.Extent(1)+1 xl.Position(2) 0];
t1.Units = 'data';
t2 = text(0,0,'$\lambda_r = \frac{di}{dt}$','Interpreter','latex','fontsize',12);
t2.VerticalAlignment = t1.VerticalAlignment;
t2.Position = [t1.Extent(1)+t1.Extent(3) t1.Position(2) 0];
t3 = text(0,0,' and so on','fontname','Vladimir Script','fontsize',12);
t3.VerticalAlignment = t2.VerticalAlignment;
t3.Position = [t2.Extent(1)+t2.Extent(3) t2.Position(2) 0];
xlabel(''); % Delete the x-label

% A mixed latex and other fonts y-label
% Create the label in LaTex to get the position
yl=ylabel('{Time (s)} $\lambda_r = \frac{di}{dt}$ and so on','Interpreter','latex','fontsize',12,'margin',1,'Units','pixels');
% Create the text replacements
t1= text(0,0,'Time (s) ','fontsize',12,'fontname','Vladimir Script','Units','pixels','rotation',90);
t1.VerticalAlignment = yl. VerticalAlignment;
t1.Position = [yl.Position(1) yl.Extent(2)+1 0];
t1.Units = 'data';
t2 = text(0,0,'$\lambda_r = \frac{di}{dt}$','Interpreter','latex','fontsize',12,'rotation',90);
t2.VerticalAlignment = t1.VerticalAlignment;
t2.Position = [t1.Position(1) t1.Extent(2)+t1.Extent(4) 0];
t3 = text(0,0,' and so on','fontname','Harrington','fontsize',12,'rotation',90);
t3.VerticalAlignment = t2.VerticalAlignment;
t3.Position = [t2.Position(1) t2.Extent(2)+t2.Extent(4) 0];
ylabel(''); % Delete the y-label

% Different text and LaTex texts and y-label
ax.FontName = 'Times New Roman';
text(0.5,0.1,'Is this Latex? No.','fontsize',14,'fontname','Vladimir Script');
text(0.5,.3,' This is \LaTeX, $I^{bet}_{you}$ it is','interpreter','latex');
text(0.5,.5,'No LaTex text','fontname','Harrington');

% A LaTex in the middle example with mixed fonts (middle aligned)
t1 = text(.1,1,'I begin Comic Sans and then ','fontname','Comic Sans MS','VerticalAlignment','middle');
t2 = text(0,0,'$\int^{love}_{LaTex}\sin{t} dt$','Interpreter','latex','VerticalAlignment','middle');
t2.Position = [t1.Extent(1)+t1.Extent(3) t1.Position(2) 0]; % Calculate position
t3 = text(0,0,', continuing in Vladimir Script','fontname','Vladimir Script','VerticalAlignment','middle');
t3.Position = [t2.Extent(1)+t2.Extent(3) t2.Position(2) 0]; % Calculate position

%% A LaTex in the middle example with mixed fonts (bottom aligned)
t1 = text(.1,.8,'I begin Comic Sans and then ','fontname','Comic Sans MS','VerticalAlignment','bottom');
t2 = text(0,0,'$\int^{love}_{LaTex}\sin{t} dt$','Interpreter','latex','VerticalAlignment','bottom');
t2.Position = [t1.Extent(1)+t1.Extent(3) t1.Position(2) 0];
t3 = text(0,0,' and then continue in Vladimir Script','fontname','Vladimir Script','VerticalAlignment','bottom');
t3.Position = [t2.Extent(1)+t2.Extent(3) t2.Position(2) 0];

%% A LaTex in the middle example with mixed fonts (middle aligned and rotated)
angle = 35; % rotation angle in degrees [-90 90]
t1 = text(.05,.05,'Comic Sans then ','fontname','Comic Sans MS','margin',1,'VerticalAlignment','middle');
t1.Units = 'centimeters'; % I change units after defining the text to write the position in data units
length = t1.Extent(3);
t1.Rotation = angle;
brx = t1.Position(1)+length*cosd(angle);
bry = t1.Position(2)+length*sind(angle);
t2 = text(brx,bry,'$\int^{love}_{LaTex}\sin{t} dt$','Interpreter','latex','margin',1,'VerticalAlignment','middle','Units','centimeters');
length = t2.Extent(3);
t2.Rotation = angle;
brx = t2.Position(1)+length*cosd(angle);
bry = t2.Position(2)+length*sind(angle);
t3 = text(brx,bry,' and Vladimir Script','fontname','Vladimir Script','rotation',angle,'margin',1,'VerticalAlignment','middle','Units','centimeters');
t3.Rotation = angle;


% 3- Preprocess. Remap the fonts to the Matlab subset
% Find font objects
font1 = findall(gcf,'fontname','Times New Roman');
font2 = findall(gcf,'fontname','Comic Sans MS');
font3 = findall(gcf,'fontname','Harrington');
font4 = findall(gcf,'fontname','Vladimir Script');

% Replace fonts
% Important Note: axes font must be remapped BEFORE the xlabel and ylabel
% remap 
set(font1,'Fontname','Times-Roman'); 
set(font2,'Fontname','courier','fontangle','italic'); 
set(font3,'Fontname','courier');
set(font4,'Fontname','courier','fontweight','bold');


% 4- Obtain the eps
set(fig,'paperpositionmode','auto','units','centimeters','paperunits','centimeters','papersize',[fig.Position(3) fig.Position(4)]);
file_name = 'Example6';
print(fig,'-depsc','-painters','-r600','-loose',strcat('.\',file_name));   % eps 


% 5- Recover the fonts
set(font1,'Fontname','Times New Roman');
set(font2,'Fontname','Comic Sans MS');
set(font3,'Fontname','Harrington');
set(font4,'Fontname','Vladimir Script');


% 6- Obtain the pdf
system(sprintf('epstopdf --gsopt="-sFONTMAP=""K:/Documentos archivados/M Files/Megaplot/FontExample6.gs""  -sFONTPATH=C:/Windows/Fonts  -dSubsetFonts=true  -dEmbedAllFonts=true -dPDFSETTINGS=/prepress" "%s.eps"',strcat('.\',file_name))) %keeps colormap
  
% 7- Open the pdf with the program of your choice
system(sprintf('"C:/Program Files/SumatraPDF/SumatraPDF.exe" -reuse-instance %s',strcat('.\',file_name,'.pdf &')));